# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Column(Component):
    """A Column component.
Row Column

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional):
    The children of the element.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- className (string; default ''):
    Specify a custom className to be applied to the `Column`.

- lg (optional):
    Specify column span for the `lg` breakpoint (Default breakpoint up
    to 1312px) This breakpoint supports 16 columns by default.  @see
    https://www.carbondesignsystem.com/guidelines/layout#breakpoints.

- max (optional):
    Specify column span for the `max` breakpoint. This breakpoint
    supports 16 columns by default.  @see
    https://www.carbondesignsystem.com/guidelines/layout#breakpoints.

- md (optional):
    Specify column span for the `md` breakpoint (Default breakpoint up
    to 1056px) This breakpoint supports 8 columns by default.  @see
    https://www.carbondesignsystem.com/guidelines/layout#breakpoints.

- sm (optional):
    Specify column span for the `sm` breakpoint (Default breakpoint up
    to 672px) This breakpoint supports 4 columns by default.  @see
    https://www.carbondesignsystem.com/guidelines/layout#breakpoints.

- style (dict; optional):
    The inline styles.

- xlg (optional):
    Specify column span for the `xlg` breakpoint (Default breakpoint
    up to 1584px) This breakpoint supports 16 columns by default.
    @see
    https://www.carbondesignsystem.com/guidelines/layout#breakpoints."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'Column'
    @_explicitize_args
    def __init__(self, children=None, style=Component.UNDEFINED, id=Component.UNDEFINED, className=Component.UNDEFINED, lg=Component.UNDEFINED, max=Component.UNDEFINED, md=Component.UNDEFINED, sm=Component.UNDEFINED, xlg=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'lg', 'max', 'md', 'sm', 'style', 'xlg']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'lg', 'max', 'md', 'sm', 'style', 'xlg']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Column, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class NumberInput(Component):
    """A NumberInput component.
NumberInput component

Keyword arguments:

- id (string; required):
    Specify a custom `id` for the input.

- allowEmpty (boolean; default False):
    `True` to allow empty string.

- ariaLabel (string; default 'Numeric input field with increment and decrement buttons'):
    Provide a description that would be used to best describe the use
    case of the NumberInput component.

- className (string; optional):
    Specify an optional className to be applied to the wrapper node.

- defaultValue (number | string; optional):
    Optional starting value for uncontrolled state.

- disabled (boolean; default False):
    Specify if the control should be disabled, or not.

- helperText (string; default ''):
    Provide text that is used alongside the control label for
    additional help.

- hideLabel (boolean; default False):
    Specify whether you want the underlying label to be visually
    hidden.

- iconDescription (string; default 'choose a number'):
    Provide a description for up/down icons that can be read by screen
    readers.

- invalid (boolean; default False):
    Specify if the currently value is invalid.

- invalidText (string; default 'Provide invalidText'):
    Message which is displayed if the value is invalid.

- label (string; optional):
    Generic `label` that will be used as the textual representation of
    what this field is for.

- light (boolean; default False):
    `True` to use the light version.

- max (number; optional):
    The maximum value.

- min (number; optional):
    The minimum value.

- readOnly (boolean; optional):
    Specify if the component should be read-only.

- size (a value equal to: 'sm', 'xl'; optional):
    Specify the size of the Number Input. Currently supports either
    `sm` or `xl` as an option.

- step (number; default 1):
    Specify how much the valus should increase/decrease upon clicking
    on up/down button.

- style (dict; optional):
    style of the input.

- value (number | string; optional):
    Specify the value of the input.

- warn (boolean; default False):
    Specify whether the control is currently in warning state.

- warnText (string; default ''):
    Provide the text that is displayed when the control is in warning
    state."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'NumberInput'
    @_explicitize_args
    def __init__(self, allowEmpty=Component.UNDEFINED, style=Component.UNDEFINED, ariaLabel=Component.UNDEFINED, className=Component.UNDEFINED, defaultValue=Component.UNDEFINED, disabled=Component.UNDEFINED, helperText=Component.UNDEFINED, hideLabel=Component.UNDEFINED, iconDescription=Component.UNDEFINED, id=Component.REQUIRED, invalid=Component.UNDEFINED, invalidText=Component.UNDEFINED, label=Component.UNDEFINED, light=Component.UNDEFINED, max=Component.UNDEFINED, min=Component.UNDEFINED, readOnly=Component.UNDEFINED, size=Component.UNDEFINED, step=Component.UNDEFINED, value=Component.UNDEFINED, warn=Component.UNDEFINED, warnText=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'allowEmpty', 'ariaLabel', 'className', 'defaultValue', 'disabled', 'helperText', 'hideLabel', 'iconDescription', 'invalid', 'invalidText', 'label', 'light', 'max', 'min', 'readOnly', 'size', 'step', 'style', 'value', 'warn', 'warnText']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'allowEmpty', 'ariaLabel', 'className', 'defaultValue', 'disabled', 'helperText', 'hideLabel', 'iconDescription', 'invalid', 'invalidText', 'label', 'light', 'max', 'min', 'readOnly', 'size', 'step', 'style', 'value', 'warn', 'warnText']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(NumberInput, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Slider(Component):
    """A Slider component.
Slider

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- ariaLabelInput (string; optional):
    The ARIA label for the <input>.

- disabled (boolean; default False):
    Disabled.

- hideTextInput (boolean; default False):
    Without text input.

- inputType (string; default 'number'):
    The form element type.

- labelText (string; required):
    Label text.

- light (boolean; default False):
    Light variant.

- max (number; required):
    The maximum value.

- min (number; required):
    The minimum value.

- name (string; optional):
    Form item name.

- step (number; required):
    The step.

- stepMultiplier (number; default 5):
    The step factor for Shift+arrow keys.

- style (dict; optional):
    jsx Style.

- value (number; required):
    The value."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'Slider'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, name=Component.UNDEFINED, inputType=Component.UNDEFINED, ariaLabelInput=Component.UNDEFINED, labelText=Component.REQUIRED, disabled=Component.UNDEFINED, light=Component.UNDEFINED, hideTextInput=Component.UNDEFINED, value=Component.REQUIRED, min=Component.REQUIRED, max=Component.REQUIRED, step=Component.REQUIRED, stepMultiplier=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'ariaLabelInput', 'disabled', 'hideTextInput', 'inputType', 'labelText', 'light', 'max', 'min', 'name', 'step', 'stepMultiplier', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'ariaLabelInput', 'disabled', 'hideTextInput', 'inputType', 'labelText', 'light', 'max', 'min', 'name', 'step', 'stepMultiplier', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['labelText', 'max', 'min', 'step', 'value']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Slider, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class RadioButtonGroup(Component):
    """A RadioButtonGroup component.
Radio Group Component

Keyword arguments:

- id (string; optional):
    Specify a custom `id` for the radio group.

- className (string; optional):
    Provide an optional className to be applied to the container node.

- disabled (boolean; optional):
    Specify whether the group is disabled.

- labelPosition (a value equal to: 'left', 'right'; optional):
    Provide where label text should be placed.

- legendText (a list of or a singular dash component, string or number; optional):
    Provide a legend to the RadioButtonGroup input that you are
    exposing to the user.

- orientation (a value equal to: 'horizontal', 'vertical'; optional):
    Provide where radio buttons should be placed.

- radiosButtons (list of dicts; optional):
    The radios buttons inside this group.

    `radiosButtons` is a list of dicts with keys:

    - id (string; optional)

    - label (string; optional)

    - value (string; optional)

- style (dict; optional):
    jsx Style.

- value (string; optional):
    The value selected."""
    _children_props = ['legendText']
    _base_nodes = ['legendText', 'children']
    _namespace = 'dash_carbon_components'
    _type = 'RadioButtonGroup'
    @_explicitize_args
    def __init__(self, legendText=Component.UNDEFINED, radiosButtons=Component.UNDEFINED, id=Component.UNDEFINED, value=Component.UNDEFINED, labelPosition=Component.UNDEFINED, orientation=Component.UNDEFINED, disabled=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'disabled', 'labelPosition', 'legendText', 'orientation', 'radiosButtons', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'disabled', 'labelPosition', 'legendText', 'orientation', 'radiosButtons', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(RadioButtonGroup, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DataTable(Component):
    """A DataTable component.
DataTable

Keyword arguments:

- id (string; required):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- action (dict; optional):
    Output only, this prop will be updated every time the user press
    one action.

    `action` is a dict with keys:

    - id (string; optional)

    - timestamp (string; optional)

- actions (list of dicts; optional):
    List of custom actions avaible in this table, every time the user
    press in one of the actions the action prop will be updated with
    the id of the action and the time of the click.

    `actions` is a list of dicts with keys:

    - id (string; optional)

    - name (string; optional)

- centerElements (boolean; default False)

- className (string; optional)

- columns (list of dicts; optional):
    True to use the light version.

    `columns` is a list of dicts with keys:

    - id (string; optional)

    - name (string; optional)

- data (list; optional):
    The date format.

- description (string; optional):
    Description of the table.

- iconColumns (list; optional)

- isPageable (boolean; optional):
    Whether to paginate the table.

- isSearchable (boolean; optional):
    Whether the table should have the search input.

- isSortable (boolean; optional):
    Specify whether the table should be able to be sorted by its
    headers.

- locale (string; optional):
    Provide a string for the current locale.

- overflowMenuOnHover (boolean; optional):
    Specify whether the overflow menu (if it exists) should be shown
    always, or only on hover.

- pageSize (number; optional)

- pageSizes (list of dicts; default [    {text: 'Ten', value: 10},    {text: 'Twenty', value: 20},    {text: 'Thirty', value: 30},    {text: 'Fourty', value: 40},    {text: 'Fifty', value: 50},])

    `pageSizes` is a list of dicts with keys:

    - text (string; optional)

    - value (number; optional)

- radio (boolean; optional):
    Specify whether the control should be a radio button or inline
    checkbox.

- shouldShowBorder (boolean; optional):
    `False` If True, will remove the table border.

- size (a value equal to: 'xs', 'sm', 'md', 'lg', 'xl'; optional):
    Change the row height of table. Currently supports `xs`, `sm`,
    `md`, `lg`, and `xl`.

- stickyHeader (boolean; optional):
    Specify whether the header should be sticky. Still experimental:
    may not work with every combination of table props.

- style (dict; optional):
    jsx Style.

- title (string; optional):
    Title of the table.

- useStaticWidth (boolean; optional):
    `False` If True, will use a width of 'auto' instead of 100%.

- useZebraStyles (boolean; optional):
    `True` to add useZebraStyles striping."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'DataTable'
    @_explicitize_args
    def __init__(self, className=Component.UNDEFINED, id=Component.REQUIRED, data=Component.UNDEFINED, columns=Component.UNDEFINED, isSortable=Component.UNDEFINED, locale=Component.UNDEFINED, overflowMenuOnHover=Component.UNDEFINED, radio=Component.UNDEFINED, shouldShowBorder=Component.UNDEFINED, size=Component.UNDEFINED, stickyHeader=Component.UNDEFINED, useStaticWidth=Component.UNDEFINED, useZebraStyles=Component.UNDEFINED, title=Component.UNDEFINED, description=Component.UNDEFINED, isSearchable=Component.UNDEFINED, actions=Component.UNDEFINED, action=Component.UNDEFINED, isPageable=Component.UNDEFINED, pageSizes=Component.UNDEFINED, pageSize=Component.UNDEFINED, style=Component.UNDEFINED, centerElements=Component.UNDEFINED, iconColumns=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'action', 'actions', 'centerElements', 'className', 'columns', 'data', 'description', 'iconColumns', 'isPageable', 'isSearchable', 'isSortable', 'locale', 'overflowMenuOnHover', 'pageSize', 'pageSizes', 'radio', 'shouldShowBorder', 'size', 'stickyHeader', 'style', 'title', 'useStaticWidth', 'useZebraStyles']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'action', 'actions', 'centerElements', 'className', 'columns', 'data', 'description', 'iconColumns', 'isPageable', 'isSearchable', 'isSortable', 'locale', 'overflowMenuOnHover', 'pageSize', 'pageSizes', 'radio', 'shouldShowBorder', 'size', 'stickyHeader', 'style', 'title', 'useStaticWidth', 'useZebraStyles']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DataTable, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Checkbox(Component):
    """A Checkbox component.
Checkbox Input

Keyword arguments:

- id (string; required):
    Provide an `id` to uniquely identify the Checkbox input.

- className (string; optional):
    Specify an optional className to be applied to the <label> node.

- disabled (boolean; optional):
    Specify whether the Checkbox should be disabled.

- hideLabel (boolean; optional):
    Specify whether the label should be hidden, or not.

- label (a list of or a singular dash component, string or number; required):
    Provide a label to provide a description of the Checkbox input
    that you are exposing to the user.

- style (dict; optional):
    The inline styles.

- title (string; optional):
    Specify a title for the <label> node for the Checkbox.

- value (boolean; optional):
    Specify whether the underlying input is checked."""
    _children_props = ['label']
    _base_nodes = ['label', 'children']
    _namespace = 'dash_carbon_components'
    _type = 'Checkbox'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, label=Component.REQUIRED, hideLabel=Component.UNDEFINED, disabled=Component.UNDEFINED, value=Component.UNDEFINED, title=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'disabled', 'hideLabel', 'label', 'style', 'title', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'disabled', 'hideLabel', 'label', 'style', 'title', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id', 'label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Checkbox, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Link(Component):
    """A Link component.
Link component

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional):
    Provide the content for the Link.

- id (string; optional):
    The id of the link.

- className (string; optional):
    Provide a custom className to be applied to the containing `<a>`
    node.

- disabled (boolean; optional):
    Specify if the control should be disabled, or not.

- href (string; optional):
    Provide the `href` attribute for the `<a>` node.

- inline (boolean; optional):
    Specify whether you want the inline version of this control.

- n_clicks (number; default 0):
    Number of times this link has been clicked.

- size (a value equal to: 'sm', 'md', 'lg'; optional):
    Specify the size of the Link. Currently supports either `sm`, 'md'
    (default) or 'lg` as an option.

- style (dict; optional):
    Inline styles.

- visited (boolean; default False):
    Specify whether you want the link to receive visited styles after
    the link has been clicked."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'Link'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, inline=Component.UNDEFINED, size=Component.UNDEFINED, n_clicks=Component.UNDEFINED, visited=Component.UNDEFINED, href=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'disabled', 'href', 'inline', 'n_clicks', 'size', 'style', 'visited']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'disabled', 'href', 'inline', 'n_clicks', 'size', 'style', 'visited']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Link, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class MultiSelect(Component):
    """A MultiSelect component.
MultiSelect

Keyword arguments:

- id (string; required):
    Id of the element.

- direction (a value equal to: 'bottom, top'; optional):
    Specify the direction of the multiselect dropdown. Can be either
    top or bottom. default bottom.

- disabled (boolean; optional):
    Disable the control.

- filterable (boolean; default True):
    Specify if this component should be filterable.

- invalid (boolean; optional):
    Is the current selection invalid.

- invalidText (string; optional):
    The text to show if it is invalid.

- label (string; optional):
    Generic label that will be used as the textual representation of
    what this field is for.

- light (boolean; optional):
    True to use the light version.

- locale (string; optional):
    Specify the locale of the control. Used for the default
    compareItems used for sorting the list of items in the control.

- options (list of dicts; required):
    List of items.

    `options` is a list of string | dict with keys:

    - label (string; optional)

    - value (boolean | number | string | dict | list; optional)s

- selectionFeedback (a value equal to: 'top', 'fixed', 'top-after-reopen'; optional):
    Specify feedback (mode) of the selection. top: selected item jumps
    to top fixed: selected item stays at it's position
    top-after-reopen: selected item jump to top after reopen dropdown
    default top-after-reopen.

- size (a value equal to: 'sm', 'lg', 'xl'; optional):
    Specify the size of the ListBox. Currently supports either sm, lg
    or xl as an option.

- style (dict; optional):
    Inline style.

- titleText (string; optional):
    Provide text to be used in a <label> element that is tied to the
    multiselect via ARIA attributes.

- value (list of boolean | number | string | dict | lists; optional):
    The list of the selected items."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'MultiSelect'
    @_explicitize_args
    def __init__(self, disabled=Component.UNDEFINED, style=Component.UNDEFINED, locale=Component.UNDEFINED, light=Component.UNDEFINED, selectionFeedback=Component.UNDEFINED, direction=Component.UNDEFINED, id=Component.REQUIRED, invalid=Component.UNDEFINED, invalidText=Component.UNDEFINED, options=Component.REQUIRED, label=Component.UNDEFINED, size=Component.UNDEFINED, titleText=Component.UNDEFINED, value=Component.UNDEFINED, filterable=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'direction', 'disabled', 'filterable', 'invalid', 'invalidText', 'label', 'light', 'locale', 'options', 'selectionFeedback', 'size', 'style', 'titleText', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'direction', 'disabled', 'filterable', 'invalid', 'invalidText', 'label', 'light', 'locale', 'options', 'selectionFeedback', 'size', 'style', 'titleText', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id', 'options']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(MultiSelect, self).__init__(**args)
